==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_fields/APPROVALWORKFLOWPARAMETERID_Type.java <==

package net.datastream.schemas.mp_fields;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for APPROVALWORKFLOWPARAMETERID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="APPROVALWORKFLOWPARAMETERID_Type">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}APPROVALWORKFLOWSETUPID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}COLUMN" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "APPROVALWORKFLOWPARAMETERID_Type", propOrder = {
    "approvalworkflowsetupid",
    "column"
})
public class APPROVALWORKFLOWPARAMETERID_Type {

    @XmlElement(name = "APPROVALWORKFLOWSETUPID", required = true)
    protected STANDARDENTITYID_Type approvalworkflowsetupid;
    @XmlElement(name = "COLUMN")
    protected String column;

    /**
     * Gets the value of the approvalworkflowsetupid property.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getAPPROVALWORKFLOWSETUPID() {
        return approvalworkflowsetupid;
    }

    /**
     * Sets the value of the approvalworkflowsetupid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setAPPROVALWORKFLOWSETUPID(STANDARDENTITYID_Type value) {
        this.approvalworkflowsetupid = value;
    }

    /**
     * Gets the value of the column property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOLUMN() {
        return column;
    }

    /**
     * Sets the value of the column property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOLUMN(String value) {
        this.column = value;
    }

}

==> eam-wshub-proxyclient-12.1-4-sources.jar: net/datastream/schemas/mp_fields/APPROVALWORKFLOWPARAMETERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for APPROVALWORKFLOWPARAMETERID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="APPROVALWORKFLOWPARAMETERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}APPROVALWORKFLOWSETUPID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COLUMN" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "APPROVALWORKFLOWPARAMETERID_Type", propOrder = {
    "approvalworkflowsetupid",
    "column"
})
public class APPROVALWORKFLOWPARAMETERID_Type {

    @XmlElement(name = "APPROVALWORKFLOWSETUPID", required = true)
    protected STANDARDENTITYID_Type approvalworkflowsetupid;
    @XmlElement(name = "COLUMN")
    protected String column;

    /**
     * Gets the value of the approvalworkflowsetupid property.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getAPPROVALWORKFLOWSETUPID() {
        return approvalworkflowsetupid;
    }

    /**
     * Sets the value of the approvalworkflowsetupid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setAPPROVALWORKFLOWSETUPID(STANDARDENTITYID_Type value) {
        this.approvalworkflowsetupid = value;
    }

    /**
     * Gets the value of the column property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOLUMN() {
        return column;
    }

    /**
     * Sets the value of the column property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOLUMN(String value) {
        this.column = value;
    }

}
